
; Monitorprogramm fuer CPD2

		TITLE	CPD2DEF

		.Z80



; **********************************************************
;         Vereinbarungsteil fuer CP/M 2.2
; **********************************************************

STACK		EQU	0FF00H

RAMSTART	EQU	0F000H

TPA		EQU	0100H

;CBIOS fuer CP/M 2.2
;
BIOSBASE	EQU	0F000H
BIOSLEN		EQU	1000H		; 4096 Byte
;
BDOSBASE    	EQU	0E200H
BDOSLEN		EQU	0E00H		; 3584 Byte = 28 * 128 		
;
CCPBASE     	EQU	0DA00H	
CCPLEN		EQU	0800H		; 2048 Byte
;
EEROMCCP	EQU	0300H
EEPROMBDOS	EQU	EEROMCCP+CCPLEN	; 0B00H

;
USERLW		EQU	4	;Laufwerksregister
IOBYTE		EQU	3	;Intel I/O-Byte
;
SBDOS		EQU	BDOSBASE+6
SCCP		EQU	CCPBASE+03H


; **********************************************************
;         Vereinbarungsteil fuer die Hardware
; **********************************************************



FRQ		EQU	4			; Frequenz in MHz

	; 
	;---Kanaladressen---

; A0 = CONTSEL,  A1 = PORTSEL,  A2 = /CE

PIO1AD		EQU     11111000B		;PIO 1 A Daten
PIO1AC		EQU     11111001B		;PIO 1 A Kommandos
PIO1BD		EQU     11111010B		;PIO 1 B Daten
PIO1BC		EQU     11111011B		;PIO 1 B Kommandos

PIO2AD		EQU     11110100B		;PIO 2 A Daten
PIO2AC		EQU     11110101B		;PIO 2 A Kommandos
PIO2BD		EQU     11110110B		;PIO 2 B Daten
PIO2BC		EQU     11110111B		;PIO 2 B Kommandos



; --------------------------------------------
;
; Bitmaske fuer Mode 3 - alles Eingaenge
BITMSKAE	EQU	11111111B
; Bitmaske fuer Mode 3 - alles Ausgaenge
BITMSKAA	EQU	00000000B


; --------------------------------------------
;
; Funktionale Bezeichnung der Ports
;
D_ITPDA_PORT	EQU	PIO1AD
C_ITPDA_PORT	EQU	PIO1AC
;
D_SYS1_PORT	EQU	PIO1BD
C_SYS1_PORT	EQU	PIO1BC
;
D_SYS2_PORT	EQU	PIO2AD
C_SYS2_PORT	EQU	PIO2AC
;
D_ITP2_CON1	EQU	PIO2BD
C_ITP2_CON1	EQU	PIO2BC



; ============================================
;
;   Datenwerte der PIOs
;
; ============================================
;
;
; PIO 1 - Port A - Initialwert der Daten des Ausgaberegisters
;
D_ITPDA_IW	EQU	00000000B

; --------------------------------------------

; PIO 1 - Port B - Initialwert der Daten des Ausgaberegisters
;
; B0 = DDWR   = 1 = High wie Widerstand
; B1 = DDAC   = 1 = (Eingang)
; B2 = SDEN   = 0 = SDEN inaktiv
; B3 = SRAC   = 0 = (Eingang) 
; B4 = RAMSEL = 0 = Low wie Widerstand - ROM ist aktiv
; B5 = LED_RT = 1 = Low LED RT aus 
; B6 = LED_GE = 0 = Low LED GE aus
; B7 = LED_GN = 0 = Low LED GN aus
;
D_SYS1_IW	EQU 	00100011B


BIT_DDWR	EQU	0
BIT_DDAC	EQU	1
BIT_SDEN	EQU	2
BIT_SRAC	EQU	3

BIT_RAMSEL	EQU	4

BIT_LED_RT	EQU	5
BIT_LED_GE	EQU	6
BIT_LED_GN	EQU	7

; --------------------------------------------
;
; PIO 2 - Port A - Initialwert der Daten des Ausgaberegisters
;
; A0 = A15    = 0 = LOW wie Widerstand
; A1 = A16    = 0 = LOW wie Widerstand
; A2 = A17    = 0 = LOW wie Widerstand
; A3 = A18    = 0 = LOW wie Widerstand 
; A4 = N.N.   = 0 = LOW
; A5 = N.N.   = 0 = LOW 
; A6 = N.N.   = 0 = LOW
; A7 = N.N.   = 0 = LOW
;
D_SYS2_IW	EQU 	00000000B

PIO2ADAR	EQU 	00000000B


BIT_DAC_P1	EQU	4		; Data Acknowledge Client Port1 (Eingang)
BIT_DES_P1	EQU	5		; Data Enable Server Port1 (Ausgang)
BIT_DAT_P1	EQU	6		; Data Value Port1 (Ausgang)

BIT_DDS_P1	EQU	7		; Data Direction Server Port1





; --------------------------------------------
;
; PIO 2 - Port B - Initialwert der Daten des Ausgaberegisters
;


; ============================================
;
;   Kommandowerte der PIOs
;
; ============================================
;
;
; PIO 1 - Port A - Initialwert der Kommandos
;
C_ITPDA_IW	EQU	BITMSKAE



;
; PIO 1 - Port B - Initialwert der Kommandos
;
; Bitmaske Port B - Initialisierung
; B0 = DDWR   = 0 - Ausgang
; B1 = DDAC   = 1 - Eingang
; B2 = SDEN   = 1 - Eingang
; B3 = SRAC   = 1 - Eingang 
; B4 = RAMSEL = 0 - Ausgang
; B5 = LED_RT = 0 - Ausgang
; B6 = LED_GE = 0 - Ausgang
; B7 = LED_GN = 0 - Ausgang
;
C_SYS1_IW	EQU	00001110B



;
; PIO 2 - Port A - Initialwert der Kommandos
;
; Maske fuer Bitbetrieb PIO2 Port A
; Bitmaske Port A - Initialisierung
; A0 = A15    = 0 - Ausgang
; A1 = A16    = 0 - Ausgang
; A2 = A17    = 0 - Ausgang
; A3 = A18    = 0 - Ausgang 
; A4 = DAC_P1 = 1 - Eingang
; A5 = DES_P1 = 0 - Ausgang
; A6 = DAT_P1 = 0 - Ausgang
; A7 = N.N.   = 1 - Eingang
C_SYS2_IW	EQU	10010000B




; =======================================================================


;
; PIO 2 - Port B - Initialwert der Kommandos
;


; ITP2 Kommandos - Read-Modus
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 1 - Eingang
; B1 = D1     = 1 - Eingang
; B2 = D2     = 1 - Eingang
; B3 = D3     = 1 - Eingang
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 1 - Eingang
; B7 = SRAC   = 0 - Ausgang 

C_ITP2_RD	EQU 	01101111B	; Read-Kommando ITP2	 

; --------------------------------------------
;
; ITP2 Kommandos - Write-Modus
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 0 - Ausgang
; B1 = D1     = 0 - Ausgang
; B2 = D2     = 0 - Ausgang
; B3 = D3     = 0 - Ausgang
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 0 - Ausgang
; B7 = SRAC   = 1 - Eingang 

C_ITP2_WR	EQU 	10100000B	; Write-Kommando ITP2	
	

C_ITP2_IW	EQU	C_ITP2_WR

; B0 = D0     = X = (Eingang)
; B1 = D1     = X = (Eingang)
; B2 = D2     = X = (Eingang)
; B3 = D3     = X = (Eingang)
; B4 = DDWR   = 1 = (Ausgang) High wie Widerstand
; B5 = DDAC   = 1 = (Eingang)
; B6 = SDEN   = 0 = (Eingang) SDEN inaktiv
; B7 = SRAC   = 0 = (Eingang) 

D_ITP2_IW	EQU 	00110000B	; Initialwert-Daten ITP2


BIT_ID0		EQU	0
BIT_ID1		EQU	1
BIT_ID2		EQU	2
BIT_ID3		EQU	3

BIT_DDWR2	EQU	4
BIT_DDAC2	EQU	5
BIT_SDEN2	EQU	6
BIT_SRAC2	EQU	7





; ============================================

RE_CONST	EQU	1		; Code fuer RECEIVE CONST 
RE_CONIN	EQU	2		; Code fuer RECEIVE CONIN 
SE_CONOUT	EQU	3		; Code fuer SEND CONOUT
RE_SECNT	EQU	4		; Code fuer RECEIVE SECTOR COUNT
RE_SECTOR	EQU	5		; Code fuer RECEIVE SECTOR
RE_RD_ISEC	EQU	6		; Code fuer RECEIVE READ IMAGE SECTOR
SE_WR_ISEC	EQU	7		; Code fuer SEND WRITE IMAGE SECTOR
SE_STD		EQU	8		; Code fuer SEND SECTOR, TRACK, DRIVE
SE_LIST		EQU	9		; Code fuer SEND LIST

	;Vereinbarungsteil ROM/RAM

; ROM von 00000H bis 07FFFH
; RAM von 08000H bis 0FFFFH

RAM_D_SYS1	EQU	0FF00H
RAM_D_SYS2	EQU	RAM_D_SYS1+1
RAM_ZEIT_ZAE	EQU	RAM_D_SYS2+1


D_ITP2_TAB	EQU	RAM_ZEIT_ZAE+1
C_ITP2_TAB	EQU	D_ITP2_TAB+1

RAM_CON_TAB	EQU	C_ITP2_TAB+1








